pub struct TensorViewMut<'a, T: TensorElement> { /* private fields */ }Expand description
Implementations
Sourceimpl<'a, T: TensorElement> TensorViewMut<'a, T>
impl<'a, T: TensorElement> TensorViewMut<'a, T>
Sourcepub fn new(
data: &'a mut [T],
shape: Shape,
strides: Vec<usize>,
offset: usize,
) -> Self
pub fn new( data: &'a mut [T], shape: Shape, strides: Vec<usize>, offset: usize, ) -> Self
Create a new mutable tensor view from raw parts
Arguments
data- Mutable reference to underlying buffershape- Shape of the viewstrides- Strides for indexingoffset- Offset into parent buffer
Sourcepub fn data_mut(&mut self) -> &mut [T]
pub fn data_mut(&mut self) -> &mut [T]
Get a mutable reference to the underlying data slice
For in-place SIMD operations, this provides direct buffer access.
Sourcepub fn is_contiguous(&self) -> bool
pub fn is_contiguous(&self) -> bool
Check if the view is contiguous in memory
Sourcepub fn get_mut(&mut self, index: usize) -> Result<&mut T>
pub fn get_mut(&mut self, index: usize) -> Result<&mut T>
Get mutable element at flat index (zero-copy)
Sourcepub fn iter(&self) -> TensorViewIter<'_, T> ⓘ
pub fn iter(&self) -> TensorViewIter<'_, T> ⓘ
Create an iterator over the view’s elements
Sourcepub fn iter_mut(&mut self) -> TensorViewIterMut<'_, T> ⓘ
pub fn iter_mut(&mut self) -> TensorViewIterMut<'_, T> ⓘ
Create a mutable iterator over the view’s elements